/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.disablerecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.disablerecord.entity.BizDisableRecord;
import vip.xiaonuo.biz.modular.disablerecord.mapper.BizDisableRecordMapper;
import vip.xiaonuo.biz.modular.disablerecord.param.BizDisableRecordAddParam;
import vip.xiaonuo.biz.modular.disablerecord.param.BizDisableRecordEditParam;
import vip.xiaonuo.biz.modular.disablerecord.param.BizDisableRecordIdParam;
import vip.xiaonuo.biz.modular.disablerecord.param.BizDisableRecordPageParam;
import vip.xiaonuo.biz.modular.disablerecord.service.BizDisableRecordService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;

import java.util.List;

/**
 * 清除记录Service接口实现类
 *
 * @author fanzherong
 * @date  2025/02/14 11:33
 **/
@Service
public class BizDisableRecordServiceImpl extends ServiceImpl<BizDisableRecordMapper, BizDisableRecord> implements BizDisableRecordService {

    @Override
    public Page<BizDisableRecord> page(BizDisableRecordPageParam bizDisableRecordPageParam) {
        QueryWrapper<BizDisableRecord> queryWrapper = new QueryWrapper<BizDisableRecord>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizDisableRecordPageParam.getUserId())){
            queryWrapper.eq("bdr.user_id",bizDisableRecordPageParam.getUserId());
        }
        queryWrapper.eq("bdr.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bdr.create_time");
        Page<BizDisableRecord> pageList = this.getBaseMapper().getPageList(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizDisableRecord bizDisableRecord : pageList.getRecords()){
            if(ObjectUtil.isNotEmpty(bizDisableRecord.getPhone())){
                bizDisableRecord.setPhone(CommonCryptogramUtil.doSm4CbcDecrypt(bizDisableRecord.getPhone()));
            }
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizDisableRecordAddParam bizDisableRecordAddParam) {
        BizDisableRecord bizDisableRecord = BeanUtil.toBean(bizDisableRecordAddParam, BizDisableRecord.class);
        this.save(bizDisableRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizDisableRecordEditParam bizDisableRecordEditParam) {
        BizDisableRecord bizDisableRecord = this.queryEntity(bizDisableRecordEditParam.getId());
        BeanUtil.copyProperties(bizDisableRecordEditParam, bizDisableRecord);
        this.updateById(bizDisableRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizDisableRecordIdParam> bizDisableRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizDisableRecordIdParamList, BizDisableRecordIdParam::getId));
    }

    @Override
    public BizDisableRecord detail(BizDisableRecordIdParam bizDisableRecordIdParam) {
        return this.queryEntity(bizDisableRecordIdParam.getId());
    }

    @Override
    public BizDisableRecord queryEntity(String id) {
        BizDisableRecord bizDisableRecord = this.getById(id);
        if(ObjectUtil.isEmpty(bizDisableRecord)) {
            throw new CommonException("清除记录不存在，id值为：{}", id);
        }
        return bizDisableRecord;
    }
}
