/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.helpcenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.helpcenter.entity.HelpCenter;
import vip.xiaonuo.biz.modular.helpcenter.mapper.HelpCenterMapper;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterAddParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterEditParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterIdParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterPageParam;
import vip.xiaonuo.biz.modular.helpcenter.service.HelpCenterService;

import java.util.List;

/**
 * 帮助中心Service接口实现类
 *
 * @author fanzherong
 * @date  2025/02/05 09:38
 **/
@Service
public class HelpCenterServiceImpl extends ServiceImpl<HelpCenterMapper, HelpCenter> implements HelpCenterService {

    @Override
    public Page<HelpCenter> page(HelpCenterPageParam helpCenterPageParam) {
        QueryWrapper<HelpCenter> queryWrapper = new QueryWrapper<HelpCenter>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(helpCenterPageParam.getSortField(), helpCenterPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(helpCenterPageParam.getSortOrder());
            queryWrapper.orderBy(true, helpCenterPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(helpCenterPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(HelpCenter::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(HelpCenterAddParam helpCenterAddParam) {
        HelpCenter helpCenter = BeanUtil.toBean(helpCenterAddParam, HelpCenter.class);
        this.save(helpCenter);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(HelpCenterEditParam helpCenterEditParam) {
        HelpCenter helpCenter = this.queryEntity(helpCenterEditParam.getId());
        BeanUtil.copyProperties(helpCenterEditParam, helpCenter);
        this.updateById(helpCenter);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<HelpCenterIdParam> helpCenterIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(helpCenterIdParamList, HelpCenterIdParam::getId));
    }

    @Override
    public HelpCenter detail(HelpCenterIdParam helpCenterIdParam) {
        return this.queryEntity(helpCenterIdParam.getId());
    }

    @Override
    public HelpCenter helpCenter() {
        return this.getOne(new QueryWrapper<HelpCenter>().last("limit 1"));
    }

    @Override
    public HelpCenter queryEntity(String id) {
        HelpCenter helpCenter = this.getById(id);
        if(ObjectUtil.isEmpty(helpCenter)) {
            throw new CommonException("帮助中心不存在，id值为：{}", id);
        }
        return helpCenter;
    }
}
