/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.rebaterecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.rebaterecord.entity.BizRebateRecord;
import vip.xiaonuo.biz.modular.rebaterecord.param.BizRebateRecordAddParam;
import vip.xiaonuo.biz.modular.rebaterecord.param.BizRebateRecordEditParam;
import vip.xiaonuo.biz.modular.rebaterecord.param.BizRebateRecordIdParam;
import vip.xiaonuo.biz.modular.rebaterecord.param.BizRebateRecordPageParam;
import vip.xiaonuo.biz.modular.rebaterecord.service.BizRebateRecordService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 返利记录控制器
 *
 * @author wulei
 * @date  2025/02/06 17:39
 */
@Tag(name = "返利记录控制器")
@RestController
@Validated
public class BizRebateRecordController {

    @Resource
    private BizRebateRecordService bizRebateRecordService;

    /**
     * 获取返利记录分页
     *
     * @author wulei
     * @date  2025/02/06 17:39
     */
    @Operation(summary = "获取返利记录分页")
    @SaCheckPermission("/biz/rebaterecord/page")
    @GetMapping("/biz/rebaterecord/page")
    public CommonResult<Page<BizRebateRecord>> page(BizRebateRecordPageParam bizRebateRecordPageParam) {
        return CommonResult.data(bizRebateRecordService.page(bizRebateRecordPageParam));
    }

    /**
     * 获取用户返利记录分页
     *
     * @author wulei
     * @date  2025/02/06 17:39
     */
    @Operation(summary = "获取用户返利记录分页")
    @GetMapping("/biz/rebaterecord/userPage")
    public CommonResult<Page<BizRebateRecord>> userPage(BizRebateRecordPageParam bizRebateRecordPageParam) {
        return CommonResult.data(bizRebateRecordService.userPage(bizRebateRecordPageParam));
    }


    /**
     * 获取返利记录详情
     *
     * @author wulei
     * @date  2025/02/06 17:39
     */
    @Operation(summary = "获取返利记录详情")
    @GetMapping("/biz/rebaterecord/detail")
    public CommonResult<BizRebateRecord> detail(@Valid BizRebateRecordIdParam bizRebateRecordIdParam) {
        return CommonResult.data(bizRebateRecordService.detail(bizRebateRecordIdParam));
    }
}
