/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.recommendrecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.recommendrecord.entity.BizRecommendRecord;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordAddParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordEditParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordIdParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordPageParam;
import vip.xiaonuo.biz.modular.recommendrecord.service.BizRecommendRecordService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 推荐记录表控制器
 *
 * @author wulei
 * @date  2025/02/06 17:42
 */
@Tag(name = "推荐记录表控制器")
@RestController
@Validated
public class BizRecommendRecordController {

    @Resource
    private BizRecommendRecordService bizRecommendRecordService;

    /**
     * 获取推荐记录表分页
     *
     * @author wulei
     * @date  2025/02/06 17:42
     */
    @Operation(summary = "获取推荐记录表分页")
    @SaCheckPermission("/biz/recommendrecord/page")
    @GetMapping("/biz/recommendrecord/page")
    public CommonResult<Page<BizRecommendRecord>> page(BizRecommendRecordPageParam bizRecommendRecordPageParam) {
        return CommonResult.data(bizRecommendRecordService.page(bizRecommendRecordPageParam));
    }

    /**
     * 获取用户推荐记录分页
     *
     * @author wulei
     * @date  2025/02/06 17:42
     */
    @Operation(summary = "获取用户推荐记录分页")
    @GetMapping("/biz/recommendrecord/userPage")
    public CommonResult<Page<BizRecommendRecord>> userPage(BizRecommendRecordPageParam bizRecommendRecordPageParam) {
        return CommonResult.data(bizRecommendRecordService.userPage(bizRecommendRecordPageParam));
    }




    /**
     * 获取推荐记录表详情
     *
     * @author wulei
     * @date  2025/02/06 17:42
     */
    @Operation(summary = "获取推荐记录表详情")
    @GetMapping("/biz/recommendrecord/detail")
    public CommonResult<BizRecommendRecord> detail(@Valid BizRecommendRecordIdParam bizRecommendRecordIdParam) {
        return CommonResult.data(bizRecommendRecordService.detail(bizRecommendRecordIdParam));
    }
}
