/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.userfundchangerecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.userfundchangerecord.entity.BizUserFundChangeRecord;
import vip.xiaonuo.biz.modular.userfundchangerecord.mapper.BizUserFundChangeRecordMapper;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordAddParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordEditParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordIdParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordPageParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.service.BizUserFundChangeRecordService;

import java.util.List;

/**
 * 用户账户资金变动记录Service接口实现类
 *
 * @author wulei
 * @date  2025/02/07 11:26
 **/
@Service
public class BizUserFundChangeRecordServiceImpl extends ServiceImpl<BizUserFundChangeRecordMapper, BizUserFundChangeRecord> implements BizUserFundChangeRecordService {

    @Override
    public Page<BizUserFundChangeRecord> page(BizUserFundChangeRecordPageParam bizUserFundChangeRecordPageParam) {
        QueryWrapper<BizUserFundChangeRecord> queryWrapper = new QueryWrapper<BizUserFundChangeRecord>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizUserFundChangeRecordPageParam.getSortField(), bizUserFundChangeRecordPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizUserFundChangeRecordPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizUserFundChangeRecordPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizUserFundChangeRecordPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizUserFundChangeRecord::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizUserFundChangeRecordAddParam bizUserFundChangeRecordAddParam) {
        BizUserFundChangeRecord bizUserFundChangeRecord = BeanUtil.toBean(bizUserFundChangeRecordAddParam, BizUserFundChangeRecord.class);
        this.save(bizUserFundChangeRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizUserFundChangeRecordEditParam bizUserFundChangeRecordEditParam) {
        BizUserFundChangeRecord bizUserFundChangeRecord = this.queryEntity(bizUserFundChangeRecordEditParam.getId());
        BeanUtil.copyProperties(bizUserFundChangeRecordEditParam, bizUserFundChangeRecord);
        this.updateById(bizUserFundChangeRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizUserFundChangeRecordIdParam> bizUserFundChangeRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizUserFundChangeRecordIdParamList, BizUserFundChangeRecordIdParam::getId));
    }

    @Override
    public BizUserFundChangeRecord detail(BizUserFundChangeRecordIdParam bizUserFundChangeRecordIdParam) {
        return this.queryEntity(bizUserFundChangeRecordIdParam.getId());
    }

    @Override
    public BizUserFundChangeRecord queryEntity(String id) {
        BizUserFundChangeRecord bizUserFundChangeRecord = this.getById(id);
        if(ObjectUtil.isEmpty(bizUserFundChangeRecord)) {
            throw new CommonException("用户账户资金变动记录不存在，id值为：{}", id);
        }
        return bizUserFundChangeRecord;
    }
}
